@@ -9,6 +9,8 @@ from .R import (
     data_range,
     corr,
     first_true,
+    invert_order,
+    order,
     paste,
     paste0,
     print_timestamp,
@@ -16,20 +18,25 @@ from .R import (
     remove_common_prefix,
     remove_common_suffix,
     unique_match,
+    var,
+    which,
 )
 
 from .bayes import (
     Ar1CoefficientPrior,
+    BetaPrior,
     DoubleModel,
     GaussianSuf,
     MvnPrior,
     MvnGivenSigma,
     NormalPrior,
+    SdPrior,
     UniformPrior,
     WishartPrior,
-    SdPrior,
 )
 
+from .cbind import cbind
+
 from .density import Density
 
 from .data_table import to_data_table, to_data_frame
@@ -37,15 +44,26 @@ from .data_table import to_data_table, to_data_frame
 from .autoclean import AutoClean
 
 from .encoding import (
+    register_encoding_json_encoder,
+    Encoder,
+    MainEffectEncoder,
+    MainEffectEncoderJsonEncoder,
+    MainEffectEncoderJsonDecoder,
     EffectEncoder,
+    OneHotEncoder,
     IdentityEncoder,
     InteractionEncoder,
+    SuccessEncoder,
+    SuccessEncoderJsonEncoder,
+    SuccessEncoderJsonDecoder,
     DatasetEncoder,
+    DatasetEncoderJsonEncoder,
+    DatasetEncoderJsonDecoder,
 )
 
 from .graphics_device import get_current_graphics_device
 
-from .mcmc import suggest_burn
+from .mcmc import suggest_burn, report_progress
 
 from .plots import (
     abline,
@@ -58,8 +76,10 @@ from .plots import (
     lines,
     lty,
     mosaic_plot,
+    pairs,
     plot,
     plot_dynamic_distribution,
+    PlotDynamicDistribution,
     plot_many_ts,
     plot_grid_shape,
     plot_ts,
@@ -68,8 +88,11 @@ from .plots import (
     )
 
 from .probability import (
+    dmvn, rmvn,
     dnorm, pnorm, qnorm, rnorm,
     dgamma, pgamma, qgamma, rgamma,
+    rbeta,
+    rpois,
     rmarkov,
 )
 
