@@ -37,6 +37,36 @@ namespace BOOM {
 
     namespace {
       using Marginal = MultivariateMarginalDistributionBase;
+
+      // Convert a Matrix to an SpdMatrix.  If the matrix is non-symmetric then
+      // force symmetry and issue a warning.
+      SpdMatrix robust_spd(const Matrix &m) {
+        if (m.is_sym()) {
+          return SpdMatrix(m);
+        } else {
+          std::ostringstream msg;
+          msg << "Coercing a non-symmetric matrix to symmetry.";
+          if (m.nrow() < 10) {
+            msg << "\n"
+                << "original matrix: \n"
+                << m
+                << "\n"
+                << "symmetric matrix: \n"
+                << .5 * (m + m.transpose())
+                ;
+          } else {
+            Matrix m_view = ConstSubMatrix(m, 0, 9, 0, 9).to_matrix();
+            msg << "\n"
+                << "First 10 rows/cols of original matrix:\n"
+                << m_view
+                << "\n"
+                << "symmetric matrix:\n"
+                << .5 * (m_view + m_view.transpose());
+          }
+          report_warning(msg.str());
+          return SpdMatrix(.5 * (m + m.transpose()));
+        }
+      }
     }
 
     //--------------------------------------------------------------------------
@@ -105,7 +135,7 @@ namespace BOOM {
       Matrix increment1 = state_variance() * observation_coefficient_subset.Tmult(
           Finv * (observation_coefficient_subset * state_variance()));
 
-      SpdMatrix contemp_variance(state_variance() - increment1);
+      SpdMatrix contemp_variance(robust_spd(state_variance() - increment1));
       if (!contemp_variance.is_pos_def()) {
         std::ostringstream warn;
         warn << "Modifying variance at time " << time_index()
@@ -115,8 +145,10 @@ namespace BOOM {
         contemp_variance = contemp_eigen.closest_positive_definite();
       }
 
-      SpdMatrix increment2(model()->state_variance_matrix(time_index())->dense());
-      SpdMatrix new_state_variance(contemp_variance);
+      SpdMatrix increment2(robust_spd(model()->state_variance_matrix(
+          time_index())->dense()));
+      SpdMatrix new_state_variance(robust_spd(contemp_variance));
+
       transition.sandwich_inplace(new_state_variance);
 
       new_state_variance += increment2;
@@ -294,17 +326,21 @@ namespace BOOM {
       // u = Finv * v - K'r
       // r = T'r + Z'u
       const Selector &observed(model()->observed_status(t));
-      Ptr<SparseKalmanMatrix> observation_coefficients(
-          model()->observation_coefficients(t, observed));
       Ptr<SparseKalmanMatrix> transition(
           model()->state_transition_matrix(t));
-      Ptr<SparseKalmanMatrix> forecast_precision_ptr(
-          marg.sparse_forecast_precision());
-      const SparseKalmanMatrix &forecast_precision(
-          *forecast_precision_ptr);
-      Vector u = forecast_precision * marg.prediction_error()
-          - marg.sparse_kalman_gain(observed, forecast_precision_ptr)->Tmult(r);
-      r = transition->Tmult(r) + observation_coefficients->Tmult(u);
+      if (observed.nvars() > 0) {
+        Ptr<SparseKalmanMatrix> observation_coefficients(
+            model()->observation_coefficients(t, observed));
+        Ptr<SparseKalmanMatrix> forecast_precision_ptr(
+            marg.sparse_forecast_precision());
+        const SparseKalmanMatrix &forecast_precision(
+            *forecast_precision_ptr);
+        Vector u = forecast_precision * marg.prediction_error()
+            - marg.sparse_kalman_gain(observed, forecast_precision_ptr)->Tmult(r);
+        r = transition->Tmult(r) + observation_coefficients->Tmult(u);
+      } else {
+        r = transition->Tmult(r);
+      }
     }
     set_initial_scaled_state_error(r);
   }
@@ -366,37 +402,38 @@ namespace BOOM {
       //
       // u = Finv * v - K'r
       // r = T'r + Z'u
-      const Selector &observed(model()->observed_status(t));
-      Ptr<SparseKalmanMatrix> observation_coefficients(
-          model()->observation_coefficients(t, observed));
       Ptr<SparseKalmanMatrix> transition(
           model()->state_transition_matrix(t));
-      Ptr<SparseKalmanMatrix> forecast_precision_ptr(
-          marg.sparse_forecast_precision());
-      const SparseKalmanMatrix &forecast_precision(
-          *forecast_precision_ptr);
-      Ptr<SparseKalmanMatrix> kalman_gain(marg.sparse_kalman_gain(
-          observed, forecast_precision_ptr));
+      const Selector &observed(model()->observed_status(t));
+      if (observed.nvars() > 0) {
+        Ptr<SparseKalmanMatrix> observation_coefficients(
+            model()->observation_coefficients(t, observed));
+        Ptr<SparseKalmanMatrix> forecast_precision_ptr(
+            marg.sparse_forecast_precision());
+        const SparseKalmanMatrix &forecast_precision(
+            *forecast_precision_ptr);
+        Ptr<SparseKalmanMatrix> kalman_gain(marg.sparse_kalman_gain(
+            observed, forecast_precision_ptr));
+        NEW(SparseMatrixProduct, KZ)();
+        KZ->add_term(kalman_gain);
+        KZ->add_term(observation_coefficients);
+        NEW(SparseMatrixSum, L)();
+        L->add_term(transition);
+        L->add_term(KZ, -1);
+        Vector u = forecast_precision * marg.prediction_error()
+            - kalman_gain->Tmult(r);
 
-
-      NEW(SparseMatrixProduct, KZ)();
-      KZ->add_term(kalman_gain);
-      KZ->add_term(observation_coefficients);
-      NEW(SparseMatrixSum, L)();
-      L->add_term(transition);
-      L->add_term(KZ, -1);
-
-      Vector u = forecast_precision * marg.prediction_error()
-          - kalman_gain->Tmult(r);
-
-      // Turn r[t] into r[t-1]
-      r = transition->Tmult(r) + observation_coefficients->Tmult(u);
-
-      // Turn N[t] into N[t-1]
-      Matrix tmp = observation_coefficients->Tmult(
-          forecast_precision * observation_coefficients->dense())
-          + L->sandwich_transpose(N);
-      N = tmp;
+        // Turn r[t] into r[t-1]
+        r = transition->Tmult(r) + observation_coefficients->Tmult(u);
+        // Turn N[t] into N[t-1]
+        Matrix tmp = observation_coefficients->Tmult(
+            forecast_precision * observation_coefficients->dense())
+            + L->sandwich_transpose(N);
+        N = tmp;
+      } else {
+        r = transition->Tmult(r);
+        N = transition->sandwich_transpose(N);
+      }
 
       Vector filtered_state_mean;
       SpdMatrix filtered_state_variance;
