@@ -3,6 +3,7 @@
 #include "Models/MvnBase.hpp"
 #include "Models/MvnModel.hpp"
 #include "Models/MvnGivenScalarSigma.hpp"
+#include "Models/MvnGivenSigma.hpp"
 #include "cpputil/Ptr.hpp"
 #include "uint.hpp"
 
@@ -174,6 +175,26 @@ namespace BayesBoom {
              )
         ;
 
+    //=========================================================================
+    py::class_<MvnGivenSigma,
+               MvnBase,
+               PriorPolicy,
+               Ptr<MvnGivenSigma>>(boom, "MvnGivenSigma", py::multiple_inheritance())
+        .def(py::init(
+            [](const Vector &mu, double kappa) {
+              return new MvnGivenSigma(mu, kappa);
+            }),
+             py::arg("mu"),
+             py::arg("kappa") = 1.0,
+             "A prior distribution on the mean parameter of a multivariate "
+             "normal model.  The model is: \n   "
+             "'mean | Sigma' ~ N(mu, Sigma / kappa).\n\n"
+             "Args:\n\n"
+             "  mu:  The mean of the distribution.\n"
+             "  kappa:  The prior sample size.\n")
+        ;
+
+
   }  // Module
 
 }  // namespace BayesBoom
